/*
 * Copyright 2022 University of Liège
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#include "wMSurface.h"
#include "wProblem.h"
#include "wTag.h"
#include "wElement.h"
#include "wNode.h"

using namespace mirrors;

MSurface::MSurface(Problem &pbl, int no, std::string _MS_name, Eigen::Vector3d _x0, Eigen::Vector3d _x1, Eigen::Vector3d _x2) : Group(pbl.msh, no), MS_name(_MS_name), x0(_x0), x1(_x1), x2(_x2)
{
    for (auto e : tag->elems)
        for (auto n : e->nodes)
            nodes.push_back(n);

    pbl.MS.push_back(this);
}

MSurface::MSurface(mirrors::Problem &pbl, std::string const &name, std::string _MS_name, Eigen::Vector3d _x0, Eigen::Vector3d _x1, Eigen::Vector3d _x2) : Group(pbl.msh, name), MS_name(_MS_name), x0(_x0), x1(_x1), x2(_x2)
{
    for (auto e : tag->elems)
        for (auto n : e->nodes)
            nodes.push_back(n);

    pbl.MS.push_back(this);
}

void MSurface::write(std::ostream &out) const
{
    out << "Mirrors surface named ''" << MS_name << "'' on " << *tag << "\n";
}
