/*
 * Copyright 2022 University of Liège
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#ifndef WUNEUMANN_H
#define WUNEUMANN_H

#include "mirrors.h"
#include "wGroup.h"
#include <vector>
#include <string>
#include <Eigen/Dense>

using namespace tbox;

namespace mirrors
{

/**
 * @brief manage mechanical von Neumann BC
 */

class MIRRORS_API uNeumann : public Group
{
public:
    std::string BC_name;
    std::vector<Node *> nodes;
    Eigen::Vector3d which_dof;
    Eigen::Vector3d values;

    uNeumann(Problem &pbl, int no, std::string _BC_name, Eigen::Vector3d _which_dof, Eigen::Vector3d _values);
    uNeumann(Problem &pbl, std::string const &name, std::string _BC_name, Eigen::Vector3d _which_dof, Eigen::Vector3d _values);

#ifndef SWIG
    virtual void write(std::ostream &out) const override;
#endif
};

} // namespace mirrors

#endif //WUNEUMANN_H
